aboutgitcodebugslistschat
path: root/udp.h
diff options
context:
space:
mode:
Diffstat (limited to 'udp.h')
-rw-r--r--udp.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/udp.h b/udp.h
index 0eca1ab..785133e 100644
--- a/udp.h
+++ b/udp.h
@@ -26,15 +26,19 @@ void udp_update_l2_buf(const unsigned char *eth_d);
/**
* struct udp_ctx - Execution context for UDP
* @fwd_in: Port forwarding configuration for inbound packets
* @fwd_out: Port forwarding configuration for outbound packets
* @timer_run: Timestamp of most recent timer run
* @timeout: Timeout for unidirectional flows (in s)
* @stream_timeout: Timeout for stream-like flows (in s)
*/
struct udp_ctx {
- struct fwd_ports fwd_in;
- struct fwd_ports fwd_out;
+ struct fwd_table fwd_in;
+ struct fwd_scan scan_in;
+ struct fwd_table fwd_out;
+ struct fwd_scan scan_out;
struct timespec timer_run;
int timeout;
int stream_timeout;
@@ -26,15 +26,19 @@ void udp_update_l2_buf(const unsigned char *eth_d);
/**
* struct udp_ctx - Execution context for UDP
- * @fwd_in: Port forwarding configuration for inbound packets
- * @fwd_out: Port forwarding configuration for outbound packets
+ * @fwd_in: Forwarding table for inbound flows
+ * @scan_in: Port scanning state for inbound packets
+ * @fwd_out: Forwarding table for outbound flows
+ * @scan_out: Port scanning state for outbound packets
* @timer_run: Timestamp of most recent timer run
* @timeout: Timeout for unidirectional flows (in s)